@@ -15,15 +15,12 @@ pub struct Matcher {
 
 impl Matcher {
     pub fn new(extractor: Box<dyn Extractor>, filter: Box<dyn Filter>) -> Self {
-        Self {
-            extractor,
-            filter,
-        }
+        Self { extractor, filter }
     }
 
     pub fn do_match(&mut self, packet: &Packet, state_manager: &mut StateManager) -> bool {
         let value = self.extractor.extract(packet);
-        
+
         self.filter.filter(&value, state_manager)
     }
 }
